@@ -48,7 +48,7 @@ std::map<int, PCKEYsym> VKTable;		// Qtキーコード  -> 仮想キーコード
 //サウンド関連
 #include "audiooutputwrapper.h"
 QPointer<AudioOutputWrapper> audioOutput = nullptr;
-QThread audioThread;
+QPointer<QThread> audioThread;
 #endif
 
 //ジョイスティック関連
@@ -1055,7 +1055,9 @@ const std::string OSD_GetJoyName( int index )
 {
 #ifndef NOJOYSTICK
 	QMutexLocker lock(&joystickMutex);
-	return SDL_JoystickNameForIndex( index );
+	const char* name = SDL_JoystickNameForIndex( index );
+	std::string tname = name ? name : "(Unknown)";
+	return tname;
 #else
 	return "";
 #endif // NOJOYSTICK
@@ -1231,8 +1233,9 @@ bool OSD_OpenAudio( void* obj, CBF_SND callback, int rate, int samples )
 	}
 
 	audioOutput = new AudioOutputWrapper(device, format, callback, obj, samples);
-	audioOutput->moveToThread(&audioThread);
-	audioThread.start();
+	audioThread = new QThread(qApp);
+	audioOutput->moveToThread(audioThread);
+	audioThread->start();
 #endif
 	return true;
 }
@@ -1250,7 +1253,8 @@ void OSD_CloseAudio( void )
 	if(!audioOutput.isNull()){
 		QMetaObject::invokeMethod(audioOutput, "stop");
 		audioOutput->deleteLater();
-		audioThread.exit();
+		audioThread->exit();
+		audioThread->deleteLater();
 	}
 #endif
 }
